@@ -1,6 +1,4 @@
-# -*- coding: utf-8 -*-
-#
-# Copyright 2018-2023 Michael Samoglyadov
+# Copyright 2018-2024 Michael Samoglyadov
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,11 +14,13 @@
 
 """Recursive diff and patch for nested structures."""
 
+import pickle
+
 import nested_diff.handlers
 
 __all__ = ['Differ', 'Iterator', 'Patcher', 'diff', 'patch']
 
-__version__ = '1.3.1'
+__version__ = '1.4.0'
 __author__ = 'Michael Samoglyadov'
 __license__ = 'Apache License, Version 2.0'
 __website__ = 'https://github.com/mr-mixas/Nested-Diff.py'
@@ -33,7 +33,6 @@ TYPE_HANDLERS = (
     nested_diff.handlers.TupleHandler(),
     nested_diff.handlers.SetHandler(),
     nested_diff.handlers.FrozenSetHandler(),
-
     nested_diff.handlers.IntHandler(),
     nested_diff.handlers.FloatHandler(),
     nested_diff.handlers.StrHandler(),
@@ -41,7 +40,7 @@ TYPE_HANDLERS = (
 )
 
 
-class Differ():
+class Differ:
     """
     Compute recursive diff for two passed objects.
 
@@ -100,8 +99,17 @@ class Differ():
 
     default_differ = DEFAULT_HANDLER.diff
 
-    def __init__(self, A=True, N=True, O=True, R=True, U=True,  # noqa: E501 E741 N803
-                 trimR=False, handlers=None):
+    def __init__(
+        self,
+        A=True,  # noqa: N803
+        N=True,
+        O=True,  # noqa: E741
+        R=True,
+        U=True,
+        trimR=False,
+        dumper=None,
+        handlers=None,
+    ):
         """Initialize Differ.
 
         Args:
@@ -111,6 +119,7 @@ class Differ():
             R: Enable/disable removed items.
             U: Enable/disable unchanged items.
             trimR: When enabled will replace removed data by None.
+            dumper: Optional objects serialiser.
             handlers: A list of type handlers.
 
         """
@@ -121,6 +130,8 @@ class Differ():
         self.op_u = U
         self.op_trim_r = trimR
 
+        self.dump = dumper or pickle.dumps
+
         self._differs = {}
 
         for handler in TYPE_HANDLERS if handlers is None else handlers:
@@ -162,7 +173,7 @@ class Differ():
         self._differs[handler.handled_type] = handler.diff
 
 
-class Patcher():
+class Patcher:
     """Patch objects using nested diff."""
 
     default_patcher = DEFAULT_HANDLER.patch
@@ -186,7 +197,7 @@ class Patcher():
     def patch(self, target, ndiff):
         """Patch object using nested diff.
 
-        This method calls apropriate handler for target value according to
+        This method calls appropriate handler for target value according to
         it's type.
 
         Args:
@@ -206,16 +217,18 @@ class Patcher():
                 try:
                     patcher = self._patchers_by_ext[extension_id]
                 except KeyError:
-                    raise ValueError('unsupported extension: '
-                                     + extension_id) from None
+                    raise ValueError(
+                        f'unsupported extension: {extension_id}',
+                    ) from None
             except KeyError:
                 cls = ndiff['D'].__class__
 
                 try:
                     patcher = self._patchers_by_cls[cls]
                 except KeyError:
-                    raise ValueError('unsupported patch type: '
-                                     + cls.__name__) from None
+                    raise ValueError(
+                        f'unsupported patch type: {cls.__name__}',
+                    ) from None
 
             return patcher(self, target, ndiff)
 
@@ -234,7 +247,7 @@ class Patcher():
             self._patchers_by_ext[handler.extension_id] = handler.patch
 
 
-class Iterator():
+class Iterator:
     """Nested diff iterator."""
 
     default_iterator = DEFAULT_HANDLER.iterate_diff
@@ -256,14 +269,15 @@ class Iterator():
             self.set_handler(handler)
 
     def _get_iterator(self, ndiff):
-        """Return apropriate iterator for passed nested diff."""
+        """Return appropriate iterator for passed nested diff."""
         try:
             extension_id = ndiff['E']
             try:
                 iterator = self._iters_by_ext[extension_id]
             except KeyError:
-                raise ValueError('unsupported extension: '
-                                 + extension_id) from None
+                raise ValueError(
+                    f'unsupported extension: {extension_id}',
+                ) from None
         except KeyError:
             try:
                 iterator = self._iters_by_cls[ndiff['D'].__class__]
@@ -321,7 +335,7 @@ def diff(a, b, extra_handlers=(), **kwargs):
         kwargs: Passed to Differ's constructor as is.
 
     Returns:
-        Tuple: nested diff.
+        Nested diff.
 
     """
     differ = Differ(**kwargs)
