@@ -1,6 +1,4 @@
-# -*- coding: utf-8 -*-
-#
-# Copyright 2019-2023 Michael Samoglyadov
+# Copyright 2019-2024 Michael Samoglyadov
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -23,7 +21,7 @@ import sys
 import nested_diff
 
 
-class App():
+class App:
     """Base class for command line tools."""
 
     default_ifmt = 'auto'
@@ -35,7 +33,7 @@ class App():
     version = nested_diff.__version__
 
     def __init__(self, args=None):
-        """Initialize appplication.
+        """Initialize application.
 
         Args:
             args: Command line arguments; sys.argv used by default.
@@ -52,16 +50,23 @@ class App():
             return {}
 
         import json
+
         return json.loads(opts)
 
+    @classmethod
+    def cli(cls):
+        """Cli tool entry point."""
+        return cls().run()
+
     @property
-    def dumper(self):  # noqa D102
+    def dumper(self):
+        """Return appropriate data dumper."""
         try:
             return self.__dumper
         except AttributeError:
             self.__dumper = self.get_dumper(
                 self.args.ofmt,
-                **self._decode_fmt_opts(self.args.ofmt_opts)  # noqa C815
+                **self._decode_fmt_opts(self.args.ofmt_opts),
             )
 
             return self.__dumper
@@ -82,10 +87,9 @@ class App():
         parser.add_argument(
             '--version',
             action='version',
-            version='%(prog)s {}'.format(self.version),
+            version=f'%(prog)s {self.version}',
             help='print version and exit',
         )
-
         parser.add_argument(
             '--ifmt',
             type=str,
@@ -93,14 +97,12 @@ class App():
             choices=sorted(self.supported_ifmts),
             help='input files format; "%(default)s" is used by default',
         )
-
         parser.add_argument(
             '--ifmt-opts',
             metavar='JSON',
             type=str,
             help='input files format options (JSON string)',
         )
-
         parser.add_argument(
             '--ofmt',
             type=str,
@@ -108,7 +110,6 @@ class App():
             choices=sorted(self.supported_ofmts),
             help='output files format; "%(default)s" is used by default',
         )
-
         parser.add_argument(
             '--ofmt-opts',
             metavar='JSON',
@@ -147,11 +148,11 @@ class App():
         if fmt == 'toml':
             return TomlDumper(**kwargs)
 
-        raise RuntimeError('Unsupported output format: ' + fmt)
+        raise RuntimeError(f'Unsupported output format: {fmt}')
 
     @staticmethod
     def guess_fmt(fp, default, ignore_fps=(sys.stdin, sys.stdout, sys.stderr)):
-        """Guess format of a file object according it's extention."""
+        """Guess format of a file object according it's extension."""
         if fp in ignore_fps:
             return default
 
@@ -164,7 +165,7 @@ class App():
 
     @staticmethod
     def get_loader(fmt, **kwargs):
-        """Create data loader object accordint to passed format.
+        """Create data loader object according to passed format.
 
         Args:
             fmt: Loader format.
@@ -186,10 +187,10 @@ class App():
         if fmt == 'toml':
             return TomlLoader(**kwargs)
 
-        raise RuntimeError('Unsupported input format: ' + fmt)
+        raise RuntimeError(f'Unsupported input format: {fmt}')
 
     def load(self, file_):
-        """Load data from file using apropriate loader.
+        """Load data from file using appropriate loader.
 
         Args:
             file_: File object to load from.
@@ -208,18 +209,18 @@ class App():
 
     @staticmethod
     def override_excepthook():
-        """
-        Change default exit code for unhandled exceptions from 1 to 127.
+        """Change default exit code for unhandled exceptions from 1 to 127.
 
         Mainly for diff tool (version control systems treat 1 as difference
         in files).
 
         """
-        def overrided(*args, **kwargs):
+
+        def overridden(*args, **kwargs):
             sys.__excepthook__(*args, **kwargs)  # do all the same
             raise SystemExit(127)  # but change exit code
 
-        sys.excepthook = overrided
+        sys.excepthook = overridden
 
     def run(self):
         """App object entry point.
@@ -231,7 +232,7 @@ class App():
         raise NotImplementedError
 
 
-class Dumper():
+class Dumper:
     """Base class for data dumpers."""
 
     tty_final_new_line = False
@@ -280,7 +281,7 @@ class Dumper():
         file_.flush()
 
 
-class Loader():
+class Loader:
     """Base class for data loaders."""
 
     def decode(self, data):  # noqa U100
@@ -328,6 +329,7 @@ class JsonDumper(Dumper):
         super().__init__()
 
         import json
+
         self.encoder = json.JSONEncoder(**self.get_opts(kwargs))
 
     def encode(self, data):
@@ -365,6 +367,7 @@ class JsonLoader(Loader):
         super().__init__()
 
         import json
+
         self.decoder = json.JSONDecoder(**self.get_opts(kwargs))
 
     def decode(self, data):
@@ -386,6 +389,7 @@ class IniDumper(Dumper):
 
         import configparser
         import io
+
         self.encoder = configparser.ConfigParser(**self.get_opts(kwargs))
         self.stringio = io.StringIO()
 
@@ -410,6 +414,7 @@ class IniLoader(Loader):
         super().__init__()
 
         import configparser
+
         self.decoder = configparser.ConfigParser(**kwargs)
 
     def decode(self, data):
@@ -422,7 +427,7 @@ class IniLoader(Loader):
             for option in self.decoder.options(section):
                 out[section][option] = self.decoder.get(section, option)
 
-            # cleanup (parser accumulates all readed confs)
+            # cleanup (parser accumulates all confs)
             self.decoder.remove_section(section)
 
         return out
@@ -435,8 +440,9 @@ class TomlDumper(Dumper):
         """Initialize dumper."""
         super().__init__()
 
-        import toml
-        self.codec = toml
+        import tomli_w
+
+        self.codec = tomli_w
 
     def encode(self, data):
         """Encode data as TOML string."""
@@ -450,8 +456,12 @@ class TomlLoader(Loader):
         """Initialize loader."""
         super().__init__()
 
-        import toml
-        self.codec = toml
+        if sys.version_info >= (3, 11):
+            import tomllib  # pragma nocover
+        else:
+            import tomli as tomllib  # pragma nocover
+
+        self.codec = tomllib
 
     def decode(self, data):
         """Parse TOML string."""
@@ -471,6 +481,7 @@ class YamlDumper(Dumper):
         super().__init__()
 
         import yaml
+
         try:
             from yaml import CSafeDumper as ImportedYamlDumper
         except ImportError:
@@ -523,6 +534,7 @@ class YamlLoader(Loader):
         super().__init__()
 
         import yaml
+
         try:
             from yaml import CSafeLoader as YamlLoader
         except ImportError:
