@@ -1,6 +1,4 @@
-# -*- coding: utf-8 -*-
-#
-# Copyright 2022-2023 Michael Samoglyadov
+# Copyright 2022-2024 Michael Samoglyadov
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,10 +16,9 @@
 
 from difflib import SequenceMatcher
 from math import isnan
-from pickle import dumps
 
 
-class TypeHandler():
+class TypeHandler:
     """Base class for type handlers.
 
     Handlers provide diff, patch, generate_formatted_diff and iterate_diff
@@ -50,7 +47,7 @@ class TypeHandler():
         diff = {}
         equal = True
 
-        if dumps(a, -1) == dumps(b, -1):
+        if differ.dump(a) == differ.dump(b):
             if differ.op_u:
                 diff['U'] = a
         else:
@@ -74,7 +71,7 @@ class TypeHandler():
             Patched object.
 
         Raises:
-            ValueError: Inapropriate diff tag found.
+            ValueError: Inappropriate diff tag found.
 
         """
         try:
@@ -301,11 +298,14 @@ class DictHandler(TypeHandler):
             for tag in formatter.tags:
                 if tag in subdiff:
                     yield from formatter.generate_key(
-                        key, tag, self.handled_type, depth,
+                        key,
+                        tag,
+                        self.handled_type,
+                        depth,
                     )
                     break
 
-            yield from formatter.generate_diff(subdiff, depth=depth+1)
+            yield from formatter.generate_diff(subdiff, depth=depth + 1)
 
 
 class ListHandler(TypeHandler):
@@ -335,15 +335,15 @@ class ListHandler(TypeHandler):
 
         >>> from nested_diff import Differ
         >>>
-        >>> a = [0,1,2,3]
-        >>> b = [  1,2,4,5]
+        >>> a = [0, 1, 2, 3]
+        >>> b = [1, 2, 4, 5]
         >>>
         >>> Differ(handlers=[ListHandler()], O=False, U=False).diff(a, b)
         (False, {'D': [{'R': 0}, {'N': 4, 'I': 3}, {'A': 5}]})
         >>>
         """
-        self.lcs.set_seq1(tuple(dumps(i, -1) for i in a))
-        self.lcs.set_seq2(tuple(dumps(i, -1) for i in b))
+        self.lcs.set_seq1(tuple(differ.dump(i) for i in a))
+        self.lcs.set_seq2(tuple(differ.dump(i) for i in b))
 
         diff = []
         equal = True
@@ -469,11 +469,14 @@ class ListHandler(TypeHandler):
             for tag in formatter.tags:
                 if tag in subdiff:
                     yield from formatter.generate_key(
-                        idx, tag, self.handled_type, depth,
+                        idx,
+                        tag,
+                        self.handled_type,
+                        depth,
                     )
                     break
 
-            yield from formatter.generate_diff(subdiff, depth=depth+1)
+            yield from formatter.generate_diff(subdiff, depth=depth + 1)
 
             idx += 1
 
@@ -500,8 +503,8 @@ class TupleHandler(ListHandler):
 
         >>> from nested_diff import Differ
         >>>
-        >>> a = (  1,2,4,5)
-        >>> b = (0,1,2,3)
+        >>> a = (1, 2, 4, 5)
+        >>> b = (0, 1, 2, 3)
         >>>
         >>> Differ(handlers=[TupleHandler()], O=False, U=False).diff(a, b)
         (False, {'D': ({'A': 0}, {'N': 3, 'I': 2}, {'R': 5})})
@@ -688,12 +691,16 @@ class TextHandler(TypeHandler):
         self.lcs.set_seq2(lines_b)
 
         for group in self.lcs.get_grouped_opcodes(self.context):
-            diff.append({
-                'I': [
-                    group[0][1], group[-1][2],
-                    group[0][3], group[-1][4],
-                ],
-            })
+            diff.append(
+                {
+                    'I': [
+                        group[0][1],
+                        group[-1][2],
+                        group[0][3],
+                        group[-1][4],
+                    ],
+                },
+            )
 
             for op, i1, i2, j1, j2 in group:
                 if op == 'equal':
@@ -781,6 +788,6 @@ class TextHandler(TypeHandler):
         length = stop - start
 
         if length > 1:
-            return '{},{}'.format(start + 1, length)
+            return f'{start + 1},{length}'
 
         return str(start + 1)
